(function ($, Drupal) {
  Drupal.behaviors.csvDatatables = {
    attach: function attach(context, settings) {
      $(context)
        .find("div.csv-table")
        .each(function () {
          var link = this.getElementsByTagName("a")[0];
          if (!link) {
            return;
          }
          var div = this;

          var settings = JSON.parse(div.dataset.settings);
          if (settings.centerContent) {
            div.classList.add("center-content");
          }

          var autolink = false;
          if (settings.autolink && typeof Autolinker !== "undefined") {
            autolink = new Autolinker({
              newWindow: Boolean(settings.autolinkNewWindow),
              stripPrefix: false,
              truncate: 50,
            });
          }

          Papa.parse(link.href, {
            download: true,
            skipEmptyLines: true,
            transform: function (value) {
              if (autolink) {
                value = autolink.link(value);
              }
              return value;
            },
            complete: function (parsed) {
              var table = document.createElement("table");
              div.classList.remove("csv-table");
              if (settings.download) {
                div.insertBefore(table, div.childNodes[0]); // use inserBefore instead of prepend for IE11 compatibility
              } else {
                div.innerHTML = "";
                div.insertBefore(table, div.childNodes[0]);
              }
              div.classList.remove("hidden");
              table.className = div.className;
              // override responsive width settings
              table.setAttribute("style", "width: 100%");

              if (div.classList.contains("dataTable")) {
                settings.columns = [];

                var headerData = parsed.data.shift();
                settings.data = parsed.data;
                if (settings.data.length > 100) {
                  settings.deferRender = true;
                }

                // wrap overflow columns into details rows responsively
                if (typeof settings.responsive != "undefined") {
                  // immediately expand details row
                  if (settings.responsive === "childRowImmediate") {
                    settings.responsive = {
                      details: {
                        display:
                          $.fn.dataTable.Responsive.display.childRowImmediate,
                        type: "none",
                      },
                    };
                  } else {
                    // by default collapse details row
                    settings.columns = [
                      {
                        className: "dtr-control",
                        orderable: false,
                        data: null,
                        title: "",
                        defaultContent: "",
                      },
                    ];
                    settings.data = parsed.data.map(function (row) {
                      var _row = row;
                      _row.unshift("");
                      return _row;
                    });
                  }
                }

                var i;

                for (i = 0; i < headerData.length; i++) {
                  settings.columns.push({ title: headerData[i] });
                }

                $(table).DataTable(settings);
              } else {
                var lines = parsed.data,
                  output = [],
                  i;
                // Add header.
                output.push(
                  "<thead><tr><th>" +
                    lines[0].join("</th><th>") +
                    "</th></tr></thead><tbody>"
                );

                div.classList.remove("csv-table");
                table.classList = div.classList;
                table.innerHTML = output;

                // Add other rows.
                for (i = 1; i < lines.length; i++)
                  output.push(
                    "<tr><td>" + lines[i].join("</td><td>") + "</td></tr>"
                  );

                output = output.join("") + "</tbody>";

                table.innerHTML = output;
              }
            },
          });
        });
    },
  };
})(jQuery, Drupal);
